#
# spec file for package python-identify
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-identify
Version:        2.6.12
Release:        1.1
Summary:        File identification library for Python
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/pre-commit/identify
Source:         https://github.com/pre-commit/identify/archive/v%{version}.tar.gz#/identify-%{version}.tar.gz
# PATCH-FIX-OPENSUSE 0001-use-editdistance-not-ukkonen.patch -- ukkonen not packaged for opensuse now
Patch1:         0001-use-editdistance-not-ukkonen.patch
BuildRequires:  %{python_module editdistance}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires(post): update-alternatives
Requires(postun): update-alternatives
Recommends:     python-editdistance
BuildArch:      noarch
%python_subpackages

%description
File identification library for Python, including license file SPDX identifier.

%prep
%setup -q -n identify-%{version}
%autopatch -p1

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/identify-cli
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%post
%python_install_alternative identify-cli

%postun
%python_uninstall_alternative identify-cli

%files %{python_files}
%doc README.md
%license LICENSE
%python_alternative %{_bindir}/identify-cli
%{python_sitelib}/identify
%{python_sitelib}/identify-%{version}*info

%changelog
* Tue Jun  3 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.6.12
  * Identify common MSBuild files
  * Drop ambiguous .proj extension
- from version 2.6.11
  * Add support for `.sqlfluff`
  * Identify XSLT files
* Mon Apr 28 2025 Markéta Machová <mmachova@suse.com>
- Update to 2.6.10
  * Add support for Magik
- Convert to pyproject macros
* Tue Apr  1 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.6.9
  * Revert "add uv to interpreters list"
* Mon Feb 24 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.6.8
  * [pre-commit.ci] pre-commit autoupdate
  * feat: Register sas as an extension
  * extensions: Introduce wsdl
* Tue Feb 11 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.6.7
  * [pre-commit.ci] pre-commit autoupdate
  * Upgrade asottile/workflows
  * Add `.templ` extension
  * Add uv to interpreters list
* Tue Feb  4 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.6.6
  * [pre-commit.ci] pre-commit autoupdate
  * Add '.asm' file extension as 'asm' filetype
- from version 2.6.5
  * feat: identify .psm1 and .psd1 files as powershell
- from version 2.6.4
  * feat: identify gleam files
  * feat: identify bz3 files as bzip3 archives
  * [pre-commit.ci] pre-commit autoupdate
  * Add Tiltfile support
* Mon Dec  9 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.6.3
  * Add C# Script and F# Source and Script filetypes
  * Add bitbake extensions and files
  * feat: identify direnv files as Bash
* Wed Nov 13 2024 Dirk Müller <dmueller@suse.com>
- update to 2.6.2:
  * Fix IndexError when shebang is just '#!/usr/bin/env'
  * Add ejson extension
* Tue May  7 2024 Dirk Müller <dmueller@suse.com>
- update to 2.5.36:
  * handle Cargo.toml
* Sat Mar 16 2024 Dirk Müller <dmueller@suse.com>
- update to 2.5.35:
  * add .metal detection
* Thu Dec  7 2023 Dirk Müller <dmueller@suse.com>
- update to 2.5.33:
  * add .avsc detection
  * Identify Vagrantfile as Ruby
  * Identify .salt-lint as YAML
* Fri Nov 24 2023 Matthias Bach <marix@marix.org>
- For Leap, build this on modern Python as 3.6 is no longer
  supported.
* Wed Nov  1 2023 Matthias Fehring <buschmann23@opensuse.org>
- update to version 2.5.31
  * no changelog available, alternatively have a look at
    https://github.com/pre-commit/identify/compare/v2.2.13...v2.5.31
- use editdistance instead of ukkonen
  * Upstream changed from editdistance_s to ukkonen for performance
    reasons. Ukkonen is not now available for openSUSE. So switch
    back to editdistance for now.
  * Add 0001-use-editdistance-not-ukkonen.patch
- spec file changes
  * remove not required python-setuptools from Requires
  * upstream URL has changed to https://github.com/pre-commit/identify
  * change requirement for python-editdistance from Suggests to
    Recommends
* Wed Aug 18 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.2.13
  * Add the '.kts' extension for kotlin
- from version 2.2.12
  * add adobe illustrator's .ai extension
- from version 2.2.11
  * Detect waf wscript files as Python
  * stricter mypy settings
* Thu Jun 24 2021 Markéta Machová <mmachova@suse.com>
- update to 2.2.10
  * add few file formats
  * detect WORKSPACE files as bazel
- stick with older editdistance as it has more functionality
* Wed May 26 2021 pgajdos@suse.com
- version update to 2.2.6
  * lot of changes, no upstream changelog found
  https://github.com/pre-commit/identify/compare/v1.4.14...v2.2.6
* Wed May 26 2021 pgajdos@suse.com
- %%check: use %%pytest macro
* Mon May 25 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Thu Apr  9 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 1.4.14
  * Handle malformed shebangs
  * Add Bazel, Scheme and Idris filetypes
  * Plantuml; .puml suffix
  * Recognize .pm as perl
  * Add some common rcfiles to the list
  * fix: add 'image' tag for SVG files
  * feat: add adoc/asciidoc file extension
* Wed Sep 11 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.4.7:
  * no upstream changelog
* Tue Jul 30 2019 pgajdos@suse.com
- version update to 1.4.5
  * no upstream changelog
* Tue May 21 2019 pgajdos@suse.com
- version update to 1.4.3
  * no upstream changelog
* Tue May  7 2019 pgajdos@suse.com
- version update to 1.4.2
  * no upstream changelog
* Thu Apr  4 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v1.4.1
